@@ -1,23 +1,21 @@
 /*
  * Copyright (C) 2002 Red Hat, Inc.
  *
- * This is free software; you can redistribute it and/or modify it under
- * the terms of the GNU Library General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * This library is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as published
+ * by the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ident "$Id: dumpkeys.c,v 1.8 2005/02/15 08:49:23 kmaraas Exp $"
-#include "../config.h"
+#include <config.h>
 #ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
 #endif
@@ -44,17 +42,11 @@
 #define MODE_APPLICATION_KEYPAD		ESC "="
 #define MODE_NORMAL_KEYPAD		ESC ">"
 #define MODE_APPLICATION_CURSOR_KEYS	1
-#define MODE_SUN_FUNCTION_KEYS		1051
-#define MODE_HP_FUNCTION_KEYS		1052
-#define MODE_XTERM_FUNCTION_KEYS	1060
-#define MODE_VT220_FUNCTION_KEYS	1061
 #define MODE_ALTERNATE_SCREEN		1047
 
 enum {
 	normal = 0, application = 1
 } keypad_mode = normal, cursor_mode = normal;
-gboolean sun_fkeys = FALSE, hp_fkeys = FALSE,
-	 xterm_fkeys = FALSE, vt220_fkeys = FALSE;
 struct termios original;
 
 /* Output the DEC private mode set sequence. */
@@ -97,30 +89,6 @@ print_help(void)
 	} else {
 		g_print("NORMAL\r\n");
 	}
-	g_print(ESC "[K" "C - SUN    ");
-	if (sun_fkeys) {
-		g_print("TRUE\r\n");
-	} else {
-		g_print("FALSE\r\n");
-	}
-	g_print(ESC "[K" "D - HP     ");
-	if (hp_fkeys) {
-		g_print("TRUE\r\n");
-	} else {
-		g_print("FALSE\r\n");
-	}
-	g_print(ESC "[K" "E - XTERM  ");
-	if (xterm_fkeys) {
-		g_print("TRUE\r\n");
-	} else {
-		g_print("FALSE\r\n");
-	}
-	g_print(ESC "[K" "F - VT220  ");
-	if (vt220_fkeys) {
-		g_print("TRUE\r\n");
-	} else {
-		g_print("FALSE\r\n");
-	}
 	g_print(ESC "[K" "R - RESET\r\n");
 	g_print(ESC "[K" "Q - QUIT\r\n");
 }
@@ -138,8 +106,8 @@ reset_scrolling_region(void)
 static void
 set_scrolling_region(void)
 {
-	g_print(ESC "[10;24r");
-	g_print(ESC "[9;1H");
+	g_print(ESC "[6;24r");
+	g_print(ESC "[5;1H");
 }
 
 /* Save the current location of the cursor in the terminal's memory. */
@@ -162,16 +130,12 @@ reset(void)
 {
 	g_print(MODE_NORMAL_KEYPAD);
 	decset(MODE_APPLICATION_CURSOR_KEYS, FALSE);
-	decset(MODE_SUN_FUNCTION_KEYS, FALSE);
-	decset(MODE_HP_FUNCTION_KEYS, FALSE);
-	decset(MODE_XTERM_FUNCTION_KEYS, FALSE);
-	decset(MODE_VT220_FUNCTION_KEYS, FALSE);
 	reset_scrolling_region();
 	restore_cursor();
 }
 
 /* Cleanly exit. */
-static void
+G_GNUC_NORETURN static void
 sigint_handler(int signum)
 {
 	if (tcsetattr(STDIN_FILENO, TCSANOW, &original) != 0) {
@@ -202,17 +166,7 @@ main(int argc, char **argv)
 	}
 	original = tcattr;
 	signal(SIGINT, sigint_handler);
-	/* Here we approximate what cfmakeraw() would do, for the benefit
-	 * of systems which don't actually provide the function. */
-	tcattr.c_iflag &= ~(IGNBRK | BRKINT | PARMRK | ISTRIP |
-			    INLCR | IGNCR | ICRNL | IXON);
-	tcattr.c_oflag &= ~(OPOST);
-	tcattr.c_lflag &= ~(ECHO | ECHONL | ICANON | ISIG | IEXTEN);
-	tcattr.c_cflag &= ~(CSIZE | PARENB);
-	tcattr.c_cflag |= CS8;
-#ifdef HAVE_CFMAKERAW
 	cfmakeraw(&tcattr);
-#endif
 	if (tcsetattr(STDIN_FILENO, TCSANOW, &tcattr) != 0) {
 		perror("tcsetattr");
 		return 1;
@@ -251,30 +205,9 @@ main(int argc, char **argv)
 			decset(MODE_APPLICATION_CURSOR_KEYS,
 			       cursor_mode == application);
 			break;
-		case 'C':
-		case 'c':
-			sun_fkeys = !sun_fkeys;
-			decset(MODE_SUN_FUNCTION_KEYS, sun_fkeys);
-			break;
-		case 'D':
-		case 'd':
-			hp_fkeys = !hp_fkeys;
-			decset(MODE_HP_FUNCTION_KEYS, hp_fkeys);
-			break;
-		case 'E':
-		case 'e':
-			xterm_fkeys = !xterm_fkeys;
-			decset(MODE_XTERM_FUNCTION_KEYS, xterm_fkeys);
-			break;
-		case 'F':
-		case 'f':
-			vt220_fkeys = !vt220_fkeys;
-			decset(MODE_VT220_FUNCTION_KEYS, vt220_fkeys);
-			break;
 		case 'R':
 		case 'r':
 			keypad_mode = cursor_mode = normal;
-			sun_fkeys = hp_fkeys = xterm_fkeys = vt220_fkeys = FALSE;
 			reset();
 			break;
 		case 'Q':
@@ -294,7 +227,7 @@ main(int argc, char **argv)
 			if (saved) {
 				restore_cursor();
 			}
-			g_byte_array_append(bytes, &c, 1);
+			g_byte_array_append(bytes, (const guint8 *) &c, 1);
 			/* Wait for up to just under 1/50 second. */
 			tv.tv_sec = 0;
 			tv.tv_usec = 1000000 / 50;
@@ -303,7 +236,7 @@ main(int argc, char **argv)
 			while (select(STDIN_FILENO + 1,
 				      &readset, NULL, NULL, &tv) == 1) {
 				if (read(STDIN_FILENO, &c, 1) == 1) {
-					g_byte_array_append(bytes, &c, 1);
+					g_byte_array_append(bytes, (const guint8 *) &c, 1);
 				} else {
 					break;
 				}
